==> jc-1.4.0.tar.gz: java/lang/VMObject.h <==
// final class java.lang.VMObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f3c3a590189dfc9 java_lang_VMObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMObject_H_
#define _JC_java_lang_VMObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Cloneable$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_VMObject$sub_refs	_jc_java_lang_VMObject$sub_refs;
typedef struct _jc_java_lang_VMObject$sub_nonrefs	_jc_java_lang_VMObject$sub_nonrefs;
typedef struct _jc_java_lang_VMObject$refs	_jc_java_lang_VMObject$refs;
typedef struct _jc_java_lang_VMObject$nonrefs	_jc_java_lang_VMObject$nonrefs;
typedef struct _jc_java_lang_VMObject$object	_jc_java_lang_VMObject$object;

typedef const struct _jc_java_lang_VMObject$vmethods	_jc_java_lang_VMObject$vmethods;
typedef const struct _jc_java_lang_VMObject$vtable	_jc_java_lang_VMObject$vtable;
typedef const struct _jc_java_lang_VMObject$vtype	_jc_java_lang_VMObject$vtype;

// Constructors
extern void _jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMObject$object *);

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_VMObject$method$clone$3943fce805d80b70(_jc_env *, struct _jc_object *);
extern void _jc_java_lang_VMObject$method$notify$9552b108446647d4(_jc_env *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef(_jc_env *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59(_jc_env *, struct _jc_java_lang_Object$object *, jlong, jint);

// Virtual methods structure
struct _jc_java_lang_VMObject$vmethods {
};

// Vtable
struct _jc_java_lang_VMObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMObject$vmethods	java_lang_VMObject;
};

// Vtype
struct _jc_java_lang_VMObject$vtype {
	_jc_type			type;
	_jc_java_lang_VMObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMObject$refs {
    _jc_java_lang_VMObject$sub_refs	java_lang_VMObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMObject$sub_nonrefs	java_lang_VMObject;
};

// Object instance structure
struct _jc_java_lang_VMObject$object {
	_jc_java_lang_VMObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMObject$vtype	*vtype;
	_jc_java_lang_VMObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMObject$vtype _jc_java_lang_VMObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMObject$class_object;

#endif	/* _JC_java_lang_VMObject_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMObject.h <==
// final class java.lang.VMObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 312e45ed214d432f java_lang_VMObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMObject_H_
#define _JC_java_lang_VMObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Cloneable$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_VMObject$sub_refs	_jc_java_lang_VMObject$sub_refs;
typedef struct _jc_java_lang_VMObject$sub_nonrefs	_jc_java_lang_VMObject$sub_nonrefs;
typedef struct _jc_java_lang_VMObject$refs	_jc_java_lang_VMObject$refs;
typedef struct _jc_java_lang_VMObject$nonrefs	_jc_java_lang_VMObject$nonrefs;
typedef struct _jc_java_lang_VMObject$object	_jc_java_lang_VMObject$object;

typedef const struct _jc_java_lang_VMObject$vmethods	_jc_java_lang_VMObject$vmethods;
typedef const struct _jc_java_lang_VMObject$vtable	_jc_java_lang_VMObject$vtable;
typedef const struct _jc_java_lang_VMObject$vtype	_jc_java_lang_VMObject$vtype;

// Constructors
extern void _jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMObject$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_VMObject$method$clone$3943fce805d80b70(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_VMObject$method$getClass$2be11d215bfbfbfe(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMObject$method$notify$9552b108446647d4(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59(_jc_env *, struct _jc_java_lang_Object$object *, jlong, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMObject$vmethods {
};

// Vtable
struct _jc_java_lang_VMObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMObject$vmethods	java_lang_VMObject;
};

// Vtype
struct _jc_java_lang_VMObject$vtype {
	_jc_type			type;
	_jc_java_lang_VMObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMObject$refs {
    _jc_java_lang_VMObject$sub_refs	java_lang_VMObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMObject$sub_nonrefs	java_lang_VMObject;
};

// Object instance structure
struct _jc_java_lang_VMObject$object {
	_jc_java_lang_VMObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMObject$vtype	*vtype;
	_jc_java_lang_VMObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMObject$vtype _jc_java_lang_VMObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMObject$class_object;

#endif	/* _JC_java_lang_VMObject_H_ */
